@@ -2,7 +2,7 @@
 
 from django.test import TestCase
 
-from django_dynamic_fixture.models import *
+from django_dynamic_fixture.test_models import *
 from django_dynamic_fixture.ddf import *
 from django_dynamic_fixture.ddf import _PRE_SAVE, _POST_SAVE
 from django_dynamic_fixture.fixture_algorithms.sequential_fixture import SequentialDataFixture
@@ -104,6 +104,10 @@ class NewFullFillAttributesWithDefaultDataTest(DDFTestCase):
         instance = self.ddf.new(ModelWithDefaultValues)
         self.assertEquals('b', instance.string_with_choices_and_default)
 
+    def test_fill_field_with_possible_optgroup_choices(self):
+        instance = self.ddf.new(ModelWithDefaultValues)
+        self.assertEquals('a', instance.string_with_optgroup_choices)
+
 
 class NewFullFillAttributesWithCustomDataTest(DDFTestCase):
     def test_fields_are_filled_with_custom_attributes(self):
@@ -245,6 +249,14 @@ class ManyToManyRelationshipTest(DDFTestCase):
     def test_invalid_many_to_many_configuration(self):
         self.assertRaises(InvalidManyToManyConfigurationError, self.ddf.get, ModelWithRelationships, manytomany='a')
 
+    def test_many_to_many_through(self):
+        b1 = self.ddf.get(ModelRelated, integer=1000)
+        b2 = self.ddf.get(ModelRelated, integer=1001)
+        instance = self.ddf.get(ModelWithRelationships, manytomany_through=[b1, b2])
+        self.assertEquals(2, instance.manytomany_through.all().count())
+        self.assertEquals(1000, instance.manytomany_through.all()[0].integer)
+        self.assertEquals(1001, instance.manytomany_through.all()[1].integer)
+
 
 class NewDealWithCyclicDependenciesTest(DDFTestCase):
     def test_new_create_by_default_only_1_lap_in_cycle(self):
@@ -678,7 +690,7 @@ class ExceptionsLayoutMessagesTest(DDFTestCase):
             self.ddf.new(ModelWithUnsupportedField)
             self.fail()
         except UnsupportedFieldError as e:
-            self.assertEquals("""django_dynamic_fixture.ModelWithUnsupportedField.z""",
+            self.assertEquals("""django_dynamic_fixture.test_models.ModelWithUnsupportedField.z""",
                               str(e))
 
     def test_BadDataError(self):
@@ -687,7 +699,7 @@ class ExceptionsLayoutMessagesTest(DDFTestCase):
             self.ddf.get(ModelForIgnoreList)
             self.fail()
         except BadDataError as e:
-            self.assertEquals("""('django_dynamic_fixture.ModelForIgnoreList', IntegrityError('django_dynamic_fixture_modelforignorelist.required may not be NULL',))""",
+            self.assertEquals("""('django_dynamic_fixture.test_models.ModelForIgnoreList', IntegrityError('django_dynamic_fixture_modelforignorelist.required may not be NULL',))""",
                               str(e))
 
     def test_InvalidConfigurationError(self):
@@ -695,7 +707,7 @@ class ExceptionsLayoutMessagesTest(DDFTestCase):
             self.ddf.new(ModelWithNumbers, integer=lambda x: ''.invalidmethod())
             self.fail()
         except InvalidConfigurationError as e:
-            self.assertEquals("""('django_dynamic_fixture.ModelWithNumbers.integer', AttributeError("'str' object has no attribute 'invalidmethod'",))""",
+            self.assertEquals("""('django_dynamic_fixture.test_models.ModelWithNumbers.integer', AttributeError("'str' object has no attribute 'invalidmethod'",))""",
                               str(e))
 
     def test_InvalidManyToManyConfigurationError(self):
@@ -711,7 +723,7 @@ class ExceptionsLayoutMessagesTest(DDFTestCase):
             self.ddf.get(ModelAbstract)
             self.fail()
         except InvalidModelError as e:
-            self.assertEquals("""django_dynamic_fixture.ModelAbstract""",
+            self.assertEquals("""django_dynamic_fixture.test_models.ModelAbstract""",
                               str(e))
 
     def test_InvalidModelError_for_common_object(self):
